@@ -2,7 +2,7 @@
 "Release information about pycerberus."
 
 name = 'pycerberus'
-version = '0.3'
+version = '0.3.1'
 description = 'Highly flexible, no magic input validation library'
 long_description = '''
 pycerberus is a framework to check user data thoroughly so that you can protect
@@ -29,6 +29,12 @@ your application from malicious (or just garbled) input data.
 Changelog
 ******************************
 
+0.3.1 (07.04.2010)
+==================
+- Fixed bug due to duplicated message in DomainNameValidator/EmailAddressValidator
+- Validator can now strip inputs (False by default)
+- StringValidator now also treats '' as empty value (as well as None)
+
 0.3 (27.03.2010)
 ==================
 - Python 2.3 compatibility
